/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */
package com.sag.osami.contextstore.serialization;

import java.io.Serializable;

/**
 * An implementing class of this service interface handles the serialization and deserialization of arbitrary (not necessarily {@link Serializable}) objects.
 */
public interface ISerializationHandler {

	/**
	 * Serializes the given object. Should return null when obj is null. Must be thread-safe.
	 * 
	 * @param obj
	 *            object to be serialized
	 * @returns a String-array with two elements: <br>
	 *          0: fully qualified class name of the object <br>
	 *          1: serialized data string of the object
	 */
	String[] serialize(Object obj);

	/**
	 * Deserializes the given data. Should return null when sobj is null. Must be thread-safe.
	 * 
	 * @param sobj
	 *            the serialized data as returned by the {@link #serialize(Object)} method
	 * @return the deserialized object
	 */
	Object deserialize(String[] sobj);

}