/**
 * (c) Atos IT Solutions and Services GmbH, 2011.
 * Licensed under EUPL 1.1
 */
package com.sag.osami.contextstore.storage;

import java.util.List;

import com.sag.osami.api.context.ContextEvent;
import com.sag.osami.api.context.IContextStorage;
import com.sag.osami.contextstore.serialization.ISerializationHandler;

/**
 * This convenience implementation of an {@link ISerializedContextStorage} provides trivial implementations for the public API methods which hide the
 * (de)serialization-flags (i.e. all methods from {@link IContextStorage}), as well as a trivial setter method for the serialization handler. All public API
 * implementations simply call the corresponding (de)serialization-aware method, passing the appropriate flag.
 * <p>
 * Although it helps avoiding redundant, trivial code, it is not required to inherit from this class when implementing an own ContextStore storage.
 */
public abstract class SerializedContextStorage implements ISerializedContextStorage {

	/**
	 * Reference to the serialization handler.
	 */
	protected ISerializationHandler serializer;

	@Override
	public void setSerializer(ISerializationHandler serializer) {
		this.serializer = serializer;
	}

	@Override
	public void store(ContextEvent context) {
		store(true, context);
	}

	@Override
	public ContextEvent load(Long contextId) {
		return load(true, contextId);
	}

	@Override
	public ContextEvent[] load(List<Long> contextIds) {
		return load(true, contextIds);
	}

	@Override
	public Iterable<ContextEvent> loadLazy(List<Long> contextIds) throws UnsupportedOperationException {
		return loadLazy(true, contextIds);
	}

	@Override
	public ContextEvent[] query(String query, Object... params) {
		return query(true, query, params);
	}

	@Override
	public Iterable<ContextEvent> queryLazy(String query, Object... params) throws UnsupportedOperationException {
		return queryLazy(true, query, params);
	}
}